netapp_ontap.models.shelf_drawers API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.shelf_drawers`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class ShelfDrawersSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the ShelfDrawers object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `closed GET POST PATCH`

    The closed field of the shelf_drawers.

  `disk_count GET POST PATCH`

    The disk_count field of the shelf_drawers.

    Example: 12

  `error GET POST PATCH`

    The error field of the shelf_drawers.

  `id GET POST PATCH`

    The id field of the shelf_drawers.

  `part_number GET POST PATCH`

    The part_number field of the shelf_drawers.

    Example: 111-03071

  `serial_number GET POST PATCH`

    The serial_number field of the shelf_drawers.

    Example: 2.1604008263E10

  `state GET POST PATCH`

    The state field of the shelf_drawers.

    Valid choices:

    - ok
    - error